Change in vdsm[master]: netinfo: call variables containing a VLAN tag 'vlan_id'

osvoboda at redhat.com osvoboda at redhat.com
Tue May 19 16:28:09 UTC 2015


Ondřej Svoboda has uploaded a new change for review.

Change subject: netinfo: call variables containing a VLAN tag 'vlan_id'
......................................................................

netinfo: call variables containing a VLAN tag 'vlan_id'

Change-Id: Id77a7406b6882a24e00ac4990cc39a4ee7681f01
Signed-off-by: Ondřej Svoboda <osvoboda at redhat.com>
---
M lib/vdsm/netinfo.py
1 file changed, 7 insertions(+), 7 deletions(-)


  git pull ssh://gerrit.ovirt.org:29418/vdsm refs/changes/25/41125/1

diff --git a/lib/vdsm/netinfo.py b/lib/vdsm/netinfo.py
index bcf2477..c9c5210 100644
--- a/lib/vdsm/netinfo.py
+++ b/lib/vdsm/netinfo.py
@@ -327,22 +327,22 @@
 
 
 def getVlanBondingNic(bridge):
     """Return the (vlan, bonding, nics) tuple that belongs to bridge."""
 
     if bridge not in bridges():
         raise ValueError('unknown bridge %s' % bridge)
-    vlan = bonding = ''
+    vlan_id = bonding = ''
     nics = []
     for iface in ports(bridge):
         if iface in vlans():
-            vlan = getVlanID(iface)
+            vlan_id = getVlanID(iface)
             iface = getVlanDevice(iface)
         if iface in bondings():
             bonding = iface
             nics = slaves(iface)
         else:
             nics = [iface]
-    return vlan, bonding, nics
+    return vlan_id, bonding, nics
 
 
 def getIfaceCfg(iface):
@@ -881,7 +881,7 @@
 
     def getNicsVlanAndBondingForNetwork(self, network):
         vlan = None
-        vlanid = None
+        vlan_id = None
         bonding = None
         lnics = []
 
@@ -896,7 +896,7 @@
             if port in self.vlans:
                 assert vlan is None
                 nic = getVlanDevice(port)
-                vlanid = getVlanID(port)
+                vlan_id = getVlanID(port)
                 vlan = port  # vlan devices can have an arbitrary name
                 assert self.vlans[port]['iface'] == nic
                 port = nic
@@ -907,7 +907,7 @@
             elif port in self.nics:
                 lnics.append(port)
 
-        return lnics, vlan, vlanid, bonding
+        return lnics, vlan, vlan_id, bonding
 
     def ifaceUsers(self, iface):
         "Returns a list of entities using the interface"
@@ -327,22 +327,22 @@
 
 def getVlanBondingNic(bridge):
-    """Return the (vlan, bonding, nics) tuple that belongs to bridge."""
+    """Return the (vlan_id, bonding, nics) tuple that belongs to bridge."""
 
     if bridge not in bridges():


-- 
To view, visit https://gerrit.ovirt.org/41125
To unsubscribe, visit https://gerrit.ovirt.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Id77a7406b6882a24e00ac4990cc39a4ee7681f01
Gerrit-PatchSet: 1
Gerrit-Project: vdsm
Gerrit-Branch: master
Gerrit-Owner: Ondřej Svoboda <osvoboda at redhat.com>


More information about the vdsm-patches mailing list